# Seminar demo

1. Install engine (Docker or Podman)
2. Start alpine image

    <details>
    <summary>Solution</summary>

    ```
    docker run -it -v $(pwd):/data alpine:3.11 sh
    ```

    </details>

3. Install chromium

    <details>
    <summary>Solution</summary>

    ```
    apk add -u chromium
    ```

    </details>

4. Take screenshot with `chromium-browser`

    <details>
    <summary>Solution</summary>

    ```
    chromium-browser --no-sandbox --headless --screenshot="/data/google.png" "https://www.google.cz/"
    ```

    </details>

5. Create volume

    <details>
    <summary>Solution</summary>

    ```
    docker volume create --name=pb138-images
    ```

    </details>

6. Mount volume to `data` and pass env variable: `WEBSITE="https://www.google.cz/"`

    <details>
    <summary>Solution</summary>

    ```
    docker run -it -e WEBSITE="https://www.google.cz/" -v pb138-images:/data alpine:3.11 sh
    apk add chromium && chromium-browser --no-sandbox --headless --screenshot="/data/google.png" $WEBSITE
    ```

    </details>

7. (Advanced) Create `compose.yml` to automate this task of taking images with help of `Containerfile`.

    <details>
    <summary>Solution</summary>

    ```yml
        version: "3.7"

        services:
            snapshot:
                build:
                dockerfile: Containerfile
                context: .
                environment:
                    - WEBSITE="https://www.google.cz/"
                volumes:
                    - snapshot-storage:/data
        
            view:
                image: alpine:3.11
                command: "ls -la /data"
                volumes:
                    - snapshot-storage:/data

        volumes:
            snapshot-storage:
    ```

    </details>

8. (Advanced) Create `wordpress-compose.yml` for wordpress with postgresql/mysql as database.

    <details>
    <summary>Solution</summary>

    ```yml
       version: '3.1'
        services:

            wordpress:
                image: wordpress
                restart: always
                ports:
                    - 8080:80
                environment:
                WORDPRESS_DB_HOST: db
                WORDPRESS_DB_USER: exampleuser
                WORDPRESS_DB_PASSWORD: examplepass
                WORDPRESS_DB_NAME: exampledb
                volumes:
                    - wordpress:/var/www/html

            db:
                image: mysql:5.7
                restart: always
                environment:
                MYSQL_DATABASE: exampledb
                MYSQL_USER: exampleuser
                MYSQL_PASSWORD: examplepass
                MYSQL_RANDOM_ROOT_PASSWORD: '1'
                volumes:
                    - db:/var/lib/mysql

        volumes:
            wordpress:
            db:
    ```

    </details>

8. (LVL Docker expert) Create `minio-compose.yml` exlain Object storage and YAML anchors.

    <details>
    <summary>Solution</summary>

    https://docs.min.io/docs/deploy-minio-on-docker-compose.html

    </details>
